@@ -387,17 +387,27 @@ class VQGanVAE(nn.Module):
 
     def state_dict(self, *args, **kwargs):
         # make sure VGG is not saved in state dictionary
-        vgg = self.vgg
-        delattr(self, 'vgg')
+        has_vgg = hasattr(self, 'vgg')
+        if has_vgg:
+            vgg = self.vgg
+            delattr(self, 'vgg')
+
         state_dict = super().state_dict(*args, **kwargs)
-        self.vgg = vgg
+
+        if has_vgg:
+            self.vgg = vgg
         return state_dict
 
     def load_state_dict(self, *args, **kwargs):
-        vgg = self.vgg
-        delattr(self, 'vgg')
+        has_vgg = hasattr(self, 'vgg')
+        if has_vgg:
+            vgg = self.vgg
+            delattr(self, 'vgg')
+
         super().load_state_dict(*args, **kwargs)
-        self.vgg = vgg
+
+        if has_vgg:
+            self.vgg = vgg
 
     @property
     def codebook(self):
